<?php
  /***
  *  Copyright (C) 2007  Gisler Garcs Vargas
  *  GNU Lesser General Public
  *
  *  @package  database    
  *  @author   Gisler Garcs Vargas  <gislersoft@users.sourceforge.net>
  *  @abstract
  *  @access   public
  *  @version  1.0.0 - 16/08/2006 <br>
  *  This class provide a DAO interface for data access object.
  *  <p>Example:<p><pre><font color='#336600'>
  *    $myDb = new DAO();<br>
  *    $myArray = $myDb->query("select * from emp");<br>
  *    $myDb->close();
  *  </font></pre><br>
  */
  class DAO{
    /***
    *  The factory object (Contains the instance of the DAOFactory implementation driver).
    *  @var object DAOFactory
    *  @access private
    */
    var $_factory;
    /***
    *  Constructor method that inits the database params using the configuration file.
    *  @access public
    */
    function DAO(){
      switch (DATABASE_DAODRIVER){
        case "POSTGRESQL":  //not implemented.
                  break;
        case "ORACLE":      $this->_factory = & new OraFactory();
                  break;
        case "MYSQL":       $this->_factory = & new MysqlFactory();
                  break;
        case "OTHERDB":     //not implemented.
                  break;
        default:  $exc = new Exception(2);
                  $exc->traceLog();
                  exit;
      }    

      if ( DATABASE_DAODRIVER != "") {
        $this->_factory->init(DATABASE_HOST,DATABASE_NAME,DATABASE_USER,DATABASE_PASS,DATABASE_PORT);
      }
    }
    /***    
    *  Returns an array with data especified by the query. return 0 when fails.
    *  @param  string  query
    *  @return  array
    *  @access public
    */
    function query($query){
      return $this->_factory->query($query);
    }
    /***
    *  Executes an especific sql statements ( insert, delete , updates or procedures). return 0 when sql statement fails.
    *  @param  string  query
    *  @return  int
    *  @access public
    */
    function execute($query){
      return $this->_factory->execute($query);
    }
    /***
    *  Close the database connection, it is active or not.
    *  @access public
    */
    function close(){
      return $this->_factory->close();
    }
    /***
    *  get an array with the names of the fields of a table.
    *  @abstract
    *  @param  string  table
    *  @access  public
    */
    function getFieldsNames($pTable){
      return $this->_factory->getFieldsNames($pTable);
    }
  }
?>
