<?php
  /***
  *  Copyright (C) 2007  Gisler Garcs Vargas
  *  GNU Lesser General Public
  *
  *  @package  database  
  *  @author    Gisler Garcs Vargas  <gislersoft@users.sourceforge.net>
  *  @abstract
  *  @access  public
  *  @version  1.0.0 - 17/08/2006 <br>
  *  This class implements de DAOFactory especifications, provides a oracle conection driver.
  */
    class OraFactory extends DAOFactory{
    /***
    *  Constructor that initialize the db params, pased by the constructor arguments.
    *  @param  string  host  Ip or hostname of the database server.  
    *  @param  string  dbname  Database name, schema or database ID.
    *  @param  string  user  User name for database connection.
    *  @param  string  password  Password for database connection.
    *  @param  string  port  (Optional) Only if the implementation class need it.
    *  @abstract
    *  @access  public
    */      
    function init($host,$dbname,$user,$password,$port){
      $this->host=$host;
      $this->user=$user;
      $this->password=$password;
      $this->dbname=$dbname;
      $this->port=$port;
      
      $connection="(DESCRIPTION=(ADDRESS=(PROTOCOL=TCP)(HOST=".$this->host
      .")(PORT=".$this->port."))(CONNECT_DATA=(SERVER=DEDICATED)(SERVICE_NAME=".$this->dbname.")))";

      $this->conn = OCILogon($this->user,$this->password,$connection);
      /* check connection */
      if (!$this->conn) {
        /*Connection Fails*/
        $exception = new Exception(1);
        $exception->traceLog();
        exit;
      }
    }
    /***
    *  Returns an array, used only for select's sql statements.
    *  @param  string  query SQL statement.
    *  @return  array
    *  @abstract
    *  @access  public
    */       
    function query($query){
      $parsed = OCIParse($this->conn, $query);
      if(OCIExecute($parsed)){
        $this->resultado = array();
        while (OCIFetchInto ($parsed, $row, OCI_ASSOC)) {
            array_push($this->resultado,$row);
        }

        $cont=0;
        foreach($this->resultado as $resReg){
          $this->resultado[$cont]=array_change_key_case($resReg,CASE_LOWER);
          $cont++;
        }
        return $this->resultado;
      }else{
        /*Query Fails*/
        $exception = new Exception(0,$query);
        $exception->traceLog();
        exit;
      }
    }
    /***
    *  Executes an especific sql statements ( insert, delete , updates or procedures). return 0 when sql statement fails.
    *  @param  string  query
    *  @return  int
    *  @access public
    */     
    function execute($query){
      $parsed = OCIParse($this->conn, $query);
      if(!OCIExecute($parsed)){
        /*Query Fails*/
        $error = OCIError($parsed);
        $myError = "[ORA-".$error['code']."] ".$error['message'];
        $exception = new Exception(0,$query."(".$myError.")");
        $exception->traceLog();
        return false;
      }else{
        return true;
      }
    }
    /***
    *  Close the actual connection to the database.
    *  @abstract
    *  @access  public
    */
    function close(){
      OCILogoff($this->conn);
    }
    /***
    *  get an array with the names of the fields of a table.
    *  @abstract
    *  @return array
    *  @param  string  table
    *  @access  public
    */
    function getFieldsNames($pTable){
      $query = "SELECT * FROM ".$pTable." WHERE rownum < 0";
      $parsed = OCIParse($this->conn, $query);
      OCIExecute($parsed);
      $countColumns = OCINumCols($parsed);
      $myArray = array();
      for ($i=1; $i<=$countColumns; $i++) {
              $myArray[($i-1)] = strtolower(OCIColumnName($parsed,$i));
      }
      return $myArray;
    }
    
  }
?>
