<?php
  /***
  *  Copyright (C) 2007  Gisler Garcs Vargas
  *  GNU Lesser General Public
  *
  *  @package   database
  *  @author    Gisler Garcs Vargas  <gislersoft@users.sourceforge.net>
  *  @see       DAO::$DAO
  *  @abstract
  *  @access    public
  *  @version   1.0.0 - 16/08/2006 <br>
  *  Abstract class that provides a factory pattern for implements another DAO specifications 
  *  for diferents database drivers like oracle, mysql, postgresql, etc.
  */
  class DAOFactory{
    /***
    *  Ip or hostname in the actual network.
    *  @var string
    *  @see init()
    */
    var  $host;
    /***
    *  Store the result.
    *  @var string
    */
    var  $resultado;
    /***
    *  Database name, schema or database ID.
    *  @var string
    *  @see init()
    */
    var  $dbname;
    /***
    *  User name for database connection.
    *  @var string
    *  @see init()
    */
    var  $user;
    /***
    *  Password for database connection.
    *  @var string
    *  @see init()
    */
    var  $password;
    /***
    *  Id for the actual database server connection.
    *  @var int
    *  @see init(),close()
    */
    var $conn;

    /***
    *  Constructor that initialize the db params, pased by the constructor arguments.
    *  @param  string  host  Ip or hostname of the database server.  
    *  @param  string  dbname  Database name, schema or database ID.
    *  @param  string  user  User name for database connection.
    *  @param  string  password  Password for database connection.
    *  @param  string  port  (Optional) Only if the implementation class need it.
    *  @abstract
    *  @access  public
    */
    function init($host,$dbname,$user,$password,$port=""){}
    /***
    *  Returns an array, used only for select's sql statements.
    *  @param  string  query SQL statement.
    *  @return  array
    *  @abstract
    *  @access  public
    */
    function query($query){}
    /***
    *  Executes an especific sql statements ( insert, delete , updates or procedures). return 0 when sql statement fails.
    *  @param  string  query
    *  @return  int
    *  @access public
    */
    function execute($query){}
    /***
    *  Close the actual connection to the database.
    *  @see  $conn
    *  @abstract
    *  @access  public
    */
    function close(){}
    /***
    *  get an array with the names of the fields of a table.
    *  @abstract
    *  @param  string  table
    *  @access  public
    */
    function getFieldsNames($pTable){}

  }
?>
