<?php
  /***
  *  Copyright (C) 2007  Gisler Garcs Vargas
  *  GNU Lesser General Public
  *
  *  @package  database  
  *  @author    Gisler Garcs Vargas  <gislersoft@users.sourceforge.net>
  *  @abstract
  *  @access  public
  *  @version  1.0.0 - 16/10/2006 <br>
  *  Esta clase implementa las especificaciones de DBCommonFactory y provee acceso a tablas en Oracle
  */
  class DBCOraFactory extends DBCommonFactory{
    /***
    *  Inserta un arreglo de datos en la tabla especificada.
    *  @param  String $pTable tabla donde se insertaran los datos.
    *  @param  String $pValues arreglo de valores a ser insertados.
    *  @abstract
    *  @access  public
    */
    function insert($pTable,$pValues){ 
      $cont = 0;
      $character ="";
      $valuesReorder      = array();
      $valuesReorderType  = array();
      
      $tableFields  = $this->_DAO->getFieldsNames($pTable);
      $pValues      = array_change_key_case($pValues, CASE_UPPER);
      $keys         = array_keys($pValues);

      foreach($keys as $reg){
        $valueType = substr($reg,0,3);
        if($valueType=="TXT" || $valueType=="NUM" || $valueType=="CHK"){
            $reg = substr($reg,3,strlen($reg)-1);
            $valueReorder[$reg] = $pValues[$valueType.$reg];
            $valuesReorderType[$reg] = $valueType;
        }else{
            $valueReorder[$reg] = $pValues[$reg];
            $valuesReorderType[$reg] = "";
        }
      }
      
      foreach ($tableFields as $value){
        $value    = strtoupper($value);
        if($cont==0)  $strInsertuP .= $character.$value.$character;
        else    $strInsertuP .= ",".$character.$value.$character;

        if($cont==0){
          if($valueReorder[$value]!=""){
            if($valuesReorderType[$value]=="NUM"){
              $strInsertDown .= $valueReorder[$value];
            }else{
              $strInsertDown .= "'".$valueReorder[$value]."'";
            }
          }else{
            $strInsertDown .= "NULL";
          }
        }else{
          if($valueReorder[$value]!=""){
            if($valuesReorderType[$value]=="NUM"){
              $strInsertDown .= ",".$valueReorder[$value];
            }else{
              $strInsertDown .= ",'".$valueReorder[$value]."'";
            }
          }else{
            $strInsertDown .= ",NULL";
          }
        }
        $cont++;      
      }
      
      $strInsert = "insert into ".$pTable." (";  
      $strInsert.=$strInsertuP;
      $strInsert.=") values (";
      $strInsert.=$strInsertDown;
      $strInsert.=")";
      //activate this line for debug.
      //echo $strInsert;
      if($this->_DAO->execute($strInsert)==true){
        return true;
      }else{
        return false;
      }
    }
    /**
    *  Realiza un select de todos los campos de la tabla especificada.
    *  @param  String $pTable tabla de la que se extraeran los datos.
    *  @param  String $pOrder campo por el que se ordenaran los datos.
    *  @abstract
    *  @return array
    *  @access  public
    */
    function getAll($pTable,$pOrder){
      $myQuery = "select * from ".$pTable." order by ".$pOrder;
      $myArray = $this->_DAO->query($myQuery);      
      return $myArray;
    }
    /***
    *  Realiza un select de todos los campos especificando un filtro.
    *  retorna null si alguno de los parametros es vacio.
    *  @param  String $pTable tabla de la que se extraeran los datos.
    *  @param  String $pFiltro filtro que se usara para la tabla.
    *  @abstract
    *  @return array
    *  @access  public
    */
    function getByFilter($pTable,$pFiltro){
      if(isset($pTable)&&isset($pFiltro)){
        $myQuery = "select * from ".$pTable." where ".$pFiltro;
        $myArray = $this->_DAO->query($myQuery);
        return $myArray;
      }else return "";
    }
    /***
    *  Devuelve true si la tabla esta vacia.
    *  retorna null si el pTable es vacio.
    *  @param  String $pTable tabla a verificar.
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function isEmpty($pTable){
      if(isset($pTable)){
        $myQuery = "select 1 from ".$pTable;
        $myArray = $this->_DAO->query($myQuery);
        if(count($myArray)==0) return true;
        else return false;
      }else return "";
    }
    /***
    *  Devuelve el numero maximo de una colomuna en los registros de una tabla.
    *  si no hay datos retorna 0, si la columna no es numerica retorna null.
    *  retorna null si alguno de los dos parametros es vacio.
    *  @param  String $pTable tabla a verificar.
    *  @param  String $pColumn tabla a verificar el maximo debe ser numerica.
    *  @abstract
    *  @return int
    *  @access  public
    */
    function getMax($pTable,$pColumn){
      if(isset($pTable)&&isset($pColumn)){
        $myQuery = "select max(".$pColumn.") ".$pColumn." from ".$pTable;
        $myArray = $this->_DAO->query($myQuery);    
        //echo $myQuery."&nbsp;";
        if(!is_numeric($myArray[0][$pColumn])){
          if(isset($myArray[0][$pColumn])){
            return "";
          }
        }
        if (!isset($myArray[0][$pColumn])) return 0;
        else return $myArray[0][$pColumn]+1;
      }else return "";
    }
    /***
    *  Verifica si existe. retorna true si existe o false si no.
    *  @param  String $pTable tabla a verificar.
    *  @param  String $pFiltro el filtro
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function exists($pTable,$pFiltro){
      $myArray=$this->getByFilter($pTable,$pFiltro);
      if(count($myArray)==0){
        return false;
      }else return true;
    }
    /***
    *  Inserta el arreglo si no existe.
    *  @param  String $pTable tabla en donde se hara el insert.
    *  @param  String $pFiltro el filtro
    *  @param  String $pArray datos a insertar.
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function insertNotExists($pTable,$pFiltro,$pArray){
      if(!$this->exists($pTable,$pFiltro)){
        $this->insert($pTable,$pArray);
        return true;
      }else{
        return false;
      }
    }
    /**
    *  Ejecuta la consulta.
    *  @param  String pQuery Consulta
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function execute($pQuery){
      return $this->_DAO->execute($pQuery);
    }
  }
?>
