<?php
  /***
  *  Copyright (C) 2007  Gisler Garcs Vargas
  *  GNU Lesser General Public
  *
  *  @package  dbCommon    
  *  @author   Gisler Garcs Vargas  <gislersoft@users.sourceforge.net>
  *  @abstract
  *  @access   public
  *  @version  1.0.0 - 16/08/2006 <br>
  *  Esta clase provee una interface para las consultas mas comunes de base de datos.
  *  <p>Example:<p><pre><font color='#336600'>
  *    $myDBC = new DBCommon($myDAO);<br>
  *    $myArray = $myDBC->getAll("empleados");<br>
  *  </font></pre><br>
  */
  class DBCommon{
    /***
    *  El factory object (Constiene la instancia de DBCommonFactory).
    *  @var object DBCommonFactory
    *  @access private
    */
    var $_factory;
    /***
    *  Constructor que inicializa el objeto DAO para el acceso a datos.
    *  @param  object DAO $pDAO Objeto de tipo DAO para hacer las conexiones a la bd.
    *  @access public
    */
    function DBCommon($pDAO){
      switch (DATABASE_DAODRIVER){
        case "POSTGRESQL":  //not implemented yet.
                  break;
        case "ORACLE":      $this->_factory = & new DBCOraFactory();
                  break;
        case "MYSQL":       $this->_factory = & new DBCMysqlFactory();
                  break;
        case "OTHERDB":     //not implemented.
                  break;
        default:      $exc = new Exception(2);
                  $exc->traceLog();
                  exit;
      }    
      //Inicializamos el objeto DAO respectivo.
      $this->_factory->setDAO($pDAO);
    }
    /***
    *  Inserta un arreglo de datos en la tabla especificada.
    *  @param  String $pTable tabla donde se insertaran los datos.
    *  @param  String $pValues arreglo de valores a ser insertados.
    *  @abstract
    *  @access  public
    */
    function insert($pTable,$pValues){
      return $this->_factory->insert($pTable,$pValues);
    }
    /***
    *  Realiza un select de todos los campos de la tabla especificada.
    *  @param  String $pTable tabla de la que se extraeran los datos.
    *  @param  String $pOrder campo por el que se ordenaran los datos.
    *  @abstract
    *  @return array
    *  @access  public
    */
    function getAll($pTable,$pOrder){
      return $this->_factory->getAll($pTable,$pOrder);
    }
    /***
    *  Realiza un select de todos los campos especificando un filtro.
    *  @param  String $pTable tabla de la que se extraeran los datos.
    *  @param  String $pFiltro filtro que se usara para la tabla.
    *  @abstract
    *  @return array
    *  @access  public
    */
    function getByFilter($pTable,$pFiltro){
      return $this->_factory->getByFilter($pTable,$pFiltro);
    }
    /***
    *  Devuelve true si la tabla esta vacia.
    *  @param  String $pTable tabla a verificar.
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function isEmpty($pTable){
      return $this->_factory->isEmpty($pTable);
    }
    /***
    *  Devuelve el numero maximo de una colomuna en los registros de una tabla.
    *  si no hay datos retorna 0.
    *  @param  String $pTable tabla a verificar.
    *  @param  String $pColumn tabla a verificar el maximo debe ser numerica.
    *  @abstract
    *  @return int
    *  @access  public
    */
    function getMax($pTable,$pColumn){
      return $this->_factory->getMax($pTable,$pColumn);
    }
    /***
    *  Verifica si existe. retorna true si existe o false si no.
    *  @param  String $pTable tabla a verificar.
    *  @param  String $pFiltro el filtro
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function exists($pTable,$pFiltro){
      return $this->_factory->exist($pTable,$Filtro);
    }
    /***
    *  Inserta el arreglo si no existe.
    *  @param  String $pTable tabla en donde se hara el insert.
    *  @param  String $pFiltro el filtro
    *  @param  String $pArray datos a insertar.
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function insertNotExists($pTable,$pFiltro,$pArray){
      return $this->_factory->insertNotExists($pTable,$pFiltro,$pArray);
    }
    /***
    *  Ejecuta la consulta.
    *  @param  String pQuery Consulta
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function execute($pQuery){
      return $this->_factory->execute($pQuery);
    }
  }
?>
