<?php
  /***
  *  Copyright (C) 2007  Gisler Garcs Vargas
  *  GNU Lesser General Public
  *
  *  @package  dbCommon    
  *  @author   Gisler Garcs Vargas  <gislersoft@users.sourceforge.net>
  *  @see      DBCommon::$DBCommon
  *  @abstract
  *  @access   public
  *  @version  1.0.0 - 16/08/2006 <br>
  *  Clase abstracta que provee un patron de factoria para el manejo de consultas comunes.
  */
  class DBCommonFactory{
    /***
    *  Objeto DAO que permite la conexin con la BD.
    *  @var Object DAO
    */
    var  $_DAO;
    /***
    *  Constructor que inicializa el DAO de conexin.
    *  @param Object $pDAO recibe como parametro el objeto de conexin.
    *  @abstract
    *  @access  public
    */
    function setDAO($pDAO){
      $this->_DAO=$pDAO;  
    }
    /***
    *  Inserta un arreglo de datos en la tabla especificada.
    *  @param  String $pTable tabla donde se insertaran los datos.
    *  @param  String $pValues arreglo de valores a ser insertados.
    *  @abstract
    *  @access  public
    */
    function insert($pTable,$pValues){}
    /***
    *  Realiza un select de todos los campos de la tabla especificada.
    *  @param  String $pTable tabla de la que se extraeran los datos.
    *  @param  String $pOrder campo por el que se ordenaran los datos.
    *  @abstract
    *  @return array
    *  @access  public
    */
    function getAll($pTable,$pOrder){}
    /***
    *  Realiza un select de todos los campos especificando un filtro.
    *  @param  String $pTable tabla de la que se extraeran los datos.
    *  @param  String $pFiltro filtro que se usara para la tabla.
    *  @abstract
    *  @return array
    *  @access  public
    */
    function getByFilter($pTable,$pFiltro){}
    /***
    *  Devuelve true si la tabla esta vacia.
    *  @param  String $pTable tabla a verificar.
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function isEmpty($pTable){}
    /***
    *  Devuelve el numero maximo de una colomuna en los registros de una tabla.
    *  si no hay datos retorna 0.
    *  @param  String $pTable tabla a verificar.
    *  @param  String $pColumn tabla a verificar el maximo debe ser numerica.
    *  @abstract
    *  @return int
    *  @access  public
    */
    function getMax($pTable,$pColumn){}
    /***
    *  Verifica si existe. retorna true si existe o false si no.
    *  @param  String $pTable tabla a verificar.
    *  @param  String $pFiltro el filtro
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function exists($pTable,$pFiltro){}
    /***
    *  Inserta el arreglo si no existe.
    *  @param  String $pTable tabla en donde se hara el insert.
    *  @param  String $pFiltro el filtro
    *  @param  String $pArray datos a insertar.
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function insertNotExists($pTable,$pFiltro,$pArray){}
    /***
    *  Ejecuta la consulta.
    *  @param  String pQuery Consulta
    *  @abstract
    *  @return boolean
    *  @access  public
    */
    function execute($pQuery){}
  }
?>
