<?php
   /***
   *  Copyright (C) 2007  Gisler Garcs Vargas
   *  GNU Lesser General Public
   *
   *   @package   exception      
   *   @author    Gisler Garcs Vargas   <gislersoft@users.sourceforge.net>
   *   @abstract
   *   @access    public
   *   @version   1.0.0 - 16/08/2006 <br>
   *   Abstract class to provide a specification for an exception handler. <i>Note: the atribute exceptions must be an array.</i>
   */
   class Exception{
      /***
      * Stores the exception message.
      * @var String
      */
      var $message;
      /***
      * Stores the name of the configured language driver.
      * @var String
      */
      var $driver;
      /***
      *   Description: Constructor. Determines what driver to use, and what mode action do.
      *   param exceptionNumber
      *   param param1   (optional)
      *   @returns string
      */
      function Exception(){
         $this->driver = $this->_getLanguageDriver();
         $args=func_get_args();

         if(isset($args[0]) && is_int($args[0])){
            if(isset($args[1]) && is_string($args[1])){
               $this->message = $this->driver->getException($args[0],$args[1]);
            }else{
               $this->message = $this->driver->getException($args[0]);
            }
         }else{
            $this->message = $this->driver->getGenericException();
         }
      }
      /***
      *   Description: Private method that return the language driver selected in the EXCEPTION_LANGUAGE param.
      *   @returns ExceptionFactory
      *   @access private
      */
      function & _getLanguageDriver(){
         /*What Driver your are going to implement?*/
         switch (EXCEPTION_LANGUAGE) {
            case "SPANISH":      return   new   ELSpanishFactory();
            case "ENGLISH":      return   new   ELEnglishFactory();
            case "OTHER":        return   new   ELOtherFactory();
            default:             echo "<b>Fatal Error:</b> Not exception language set yet, verify the EXCEPTION_LANGUAGE param in the config.php file.";
                                 exit;
         }
      }
      /***
      *   Description: Public method when its called logs the exception, in the defaul mode, or especial mode.
      *   param EXCEPTION_ACTION (optional)
      *   @access public
      */
      function traceLog(){
         $ignoreDefaultLog = false;
         $args=func_get_args();

         /*Especial Log for this exception?*/
         if(isset($args[0]) && is_int($args[0])){
            $this->_doLog($args[0]);
         }else{
            $this->_doLog(EXCEPTION_ACTION);
         }
      }
      /***
      *   Description: Private method used for log the exception in the mode indicated in the option param.
      *   @param String $option Looks the actual action configuration to do the logging.
      *   @access private
      */
      function _doLog($option){
               /*What i show/log the exception?*/
               switch ($option){
                  case "DEBUG":   $this->_debug(); break;
                  case "AUDIT":   $this->_audIn(); break;
                  case "ALL":     $this->_allIn(); break;
                  case "DB":      $this->_dbIn(); break;
                  case "LOG":     $this->_logIn(); break;
                  case "FILE":    $this->_fileIn(); break;
                  default:        echo "<b>Fatal Error:</b> Invalid params for log verify the correct log values.";
                           exit;
               }
      }
      /***
      *   Description: Private method that echo the exception message.
      *   @access private
      */
      function _debug(){
         echo $this->message;
      }
      /***
      *   Description: Private method that echo the exception message and log it into db.
      *   @access private
      */
      function _audIn(){
         //Not implemented yet.
      }
      /***
      *   Description: Private method that echo the exception message and log it into db, and put into a plain file.
      *   @access private
      */
      function _allIn(){
         //Not implemented yet.
      }
      /***
      *   Description: Private method that insert the exception message into db. 
      *   @access private
      */
      function _dbIn(){
         //Not implemented yet.
      }
      /***
      *   Description: Private method that insert the exception message into db, and put into a file. 
      *   @access private
      */
      function _logIn(){
         //Not implemented yet.
      }
      /***
      *   Description: Private method that put the exception message into a file. 
      *   @access private
      */
      function _fileIn(){
         //Not implemented yet.
      }
   }
?>
